@@ -8,7 +8,7 @@ our @ISA = qw( HTTP::Server::PSGI );
 
 use Socket qw(IPPROTO_TCP TCP_NODELAY);
 
-our $VERSION = '0.23_09';
+our $VERSION = '0.23_10';
 
 use Devel::hdb::Logger qw(log);
 
@@ -142,8 +142,21 @@ sub handle_connection {
         log('response was CODEref');
         $res->(sub {
             log('running response CODEref...');
-            $self->_handle_response($_[0], $conn);
+            my $wantarray = wantarray;
+            my($rv, @rv);
+            if ($wantarray) {
+                @rv = $self->_handle_response($_[0], $conn);
+            } elsif (defined $wantarray) {
+                $rv = $self->_handle_response($_[0], $conn);
+            } else {
+                $self->_handle_response($_[0], $conn);
+            }
             log('    .... back from response CODEref');
+            if ($wantarray) {
+                return @rv;
+            } else {
+                return $rv;
+            }
         });
     } else {
         log("Bad response: $res");
